.. highlight:: shell

========================
Installation and usage
========================


* Stable release

To install mlsauce from Pypi, run this command in your terminal:

.. code-block:: console

    $ pip install mlsauce

If you don't have `pip`_ installed yet, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


* Development version

Using GitHub (having installed `pip`_ first, see previous point): 

.. code-block:: console

    $ pip install git+https://github.com/thierrymoudiki/mlsauce.git


.. _Github repo: https://github.com/thierrymoudiki/mlsauce
.. _tarball: https://github.com/thierrymoudiki/mlsauce/tarball/master


* Usage 

To use mlsauce in a project, type (in a Python module)::

    import mlsauce as ms
